Learn R Programming

radjust (version 0.1.0)

crohn: p-values of 126 SNPs followed from a primary study to a follow-up study for testing their association with Crohn's disease.

Description

To discover the associations between SNPs and Crohn's disease, 635547 SNPs were examined in a primary study. For follow-up, 126 SNPs were measured in an independent study. The criteria for follow-up were as follows: the two smallest p-values in each distinct region with primary study p-values below 0.00005.

Usage

crohn

Arguments

Format

A data frame with 126 rows and 3 columns:

index integer just the row number.
pv1 numeric p-value from study 1.

References

Bogomolov, M. and Heller, R. (2013). Discovering findings that replicate from a primary study of high dimension to a follow-up study. Journal of the American Statistical Association, Vol. 108, No. 504, Pp. 1480-1492.

See Also

the example in radjust_pf uses this data.