For FDR control at level \(\alpha\) on replicability claims, all features with \(r\)-value at most \(\alpha\) are declared
as replicated.
In addition, the discoveries from study 1 among the replicability claims have an FDR control guarantee at level \(w_{1}\alpha\).
Similarly, the discoveries from study 2 among the replicability claims have an FDR control guarantee at level \((1-w_{1})\alpha\).
Setting w1 to a value different than half is appropriate for stricter FDR control in one of the studies.
For example, if study two has a much larger sample size than study one (and both studies examine the same problem), then
setting \(w_{1} > 0.5\) will provide a stricter FDR control for the larger study and greater power for the replicability analysis,
see Bogomolov and Heller (2018) for details.
The theoretical FDR control guarantees assume independence within each vector of p-values. However, empirical
investigations suggest that the method is robust to deviations from independence. In practice, we recommend using it whenever the
Benjamini-Hochberg procedure is appropriate for use with single studies, as this procedure can be viewed as a two-dimensional
Benjamini-Hochberg procedure which enjoys similar robustness properties. For general dependence, we provide the option to apply
a more conservative procedure with theoretical FDR control guarantee for any type of dependence,
by setting general_dependency to TRUE.
If variant is "non-adaptive", then the non-adaptive replicability analysis procedure of Bogomolov and Heller (2018)
is applied on the input p-values pv1 and pv2.
If variant is "non-adaptive-with-alpha-selection", then for a user specified alpha (default 0.05) only p-values from
study one below \(w_{1}\alpha\) and from study
two below \((1-w_{1})\alpha\) are considered for replicability analysis. This additional step prevents
including in the selected sets features that cannot be discovered as replicability claims at the nominal FDR level
\(\alpha\), thus reducing the multiplicity adjustment necessary for replicability analysis. If variant is "adaptive", then for a user specified alpha
the adaptive replicability analysis procedure is applied on the dataset, see Bogomolov and Heller (2018) for details.
The meaning of the replicability claim for a feature if directional_rep_claim is FALSE, is that both null hypotheses are false (or both alternatives are true). Setting directional_rep_claim to
TRUE is useful if the discoveries of interest are directional but the direction is unknown. For example, a directional replicability
claim for a feature is the claim that both associations examined for it are positive, or both associations examined for it
are negative, but not that one association is positive and the other negative. For directional replicability analysis,
the input p-values pv1 and pv2 should be the left-sided input p-values
(left-sided is the choice without loss of generality, since we assume the left and right sided p-values sum to one for each null hypothesis).